==> libreoffice_24.2.5.orig.tar.xz: libreoffice-24.2.5.2/svx/source/items/ofaitem.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */


#include <svx/ofaitem.hxx>
#include <svx/xtable.hxx>
#include <utility>

OfaPtrItem::OfaPtrItem( sal_uInt16 _nWhich, void *_pPtr )
    : SfxPoolItem( _nWhich ), pPtr( _pPtr )
{

}

bool OfaPtrItem::operator==( const SfxPoolItem& rItem) const
{
    return SfxPoolItem::operator==(rItem) &&
        static_cast<const OfaPtrItem&>(rItem).pPtr == pPtr;
}

OfaPtrItem* OfaPtrItem::Clone( SfxItemPool * ) const
{
    return new OfaPtrItem( *this );
}

OfaXColorListItem::OfaXColorListItem( sal_uInt16 _nWhich, rtl::Reference<XColorList> xRef )
    : SfxPoolItem( _nWhich ), mxRef(std::move( xRef ))
{}

bool OfaXColorListItem::operator==( const SfxPoolItem& rItem ) const
{
    return SfxPoolItem::operator==(rItem)
        && mxRef == static_cast<OfaXColorListItem const &>(rItem).mxRef;
}

OfaXColorListItem* OfaXColorListItem::Clone( SfxItemPool* /*pPool = 0*/ ) const
{
    return new OfaXColorListItem( *this );
}

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice-25.2.0.3.tar.xz: libreoffice-25.2.0.3/svx/source/items/ofaitem.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */


#include <svx/ofaitem.hxx>
#include <svx/xtable.hxx>
#include <utility>

OfaPtrItem::OfaPtrItem( sal_uInt16 _nWhich, void *_pPtr )
    : SfxPoolItem( _nWhich, SfxItemType::OfaPtrItemType )
    , pPtr( _pPtr )
{

}

bool OfaPtrItem::operator==( const SfxPoolItem& rItem) const
{
    return SfxPoolItem::operator==(rItem) &&
        static_cast<const OfaPtrItem&>(rItem).pPtr == pPtr;
}

OfaPtrItem* OfaPtrItem::Clone( SfxItemPool * ) const
{
    return new OfaPtrItem( *this );
}

OfaXColorListItem::OfaXColorListItem( sal_uInt16 _nWhich, rtl::Reference<XColorList> xRef )
    : SfxPoolItem( _nWhich, SfxItemType::OfaXColorListItemType )
    , mxRef(std::move( xRef ))
{}

bool OfaXColorListItem::operator==( const SfxPoolItem& rItem ) const
{
    return SfxPoolItem::operator==(rItem)
        && mxRef == static_cast<OfaXColorListItem const &>(rItem).mxRef;
}

OfaXColorListItem* OfaXColorListItem::Clone( SfxItemPool* /*pPool = 0*/ ) const
{
    return new OfaXColorListItem( *this );
}

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
